summaryrefslogtreecommitdiff
path: root/src/libstrongswan/credentials/certificates/certificate.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/libstrongswan/credentials/certificates/certificate.h')
-rw-r--r--src/libstrongswan/credentials/certificates/certificate.h18
1 files changed, 10 insertions, 8 deletions
diff --git a/src/libstrongswan/credentials/certificates/certificate.h b/src/libstrongswan/credentials/certificates/certificate.h
index 43bfe3dc1..2f471da5b 100644
--- a/src/libstrongswan/credentials/certificates/certificate.h
+++ b/src/libstrongswan/credentials/certificates/certificate.h
@@ -77,6 +77,8 @@ enum cert_validation_t {
VALIDATION_STALE,
/** validation failed due to a processing error */
VALIDATION_FAILED,
+ /** certificate is on hold (i.e. temporary revokation) */
+ VALIDATION_ON_HOLD,
/** certificate has been revoked */
VALIDATION_REVOKED,
};
@@ -115,7 +117,7 @@ struct certificate_t {
* not returned by get_subject (e.g. subjectAltNames)
*
* @param subject subject identity
- * @return matching value of best match
+ * @return matching value of best match
*/
id_match_t (*has_subject)(certificate_t *this, identification_t *subject);
@@ -132,8 +134,8 @@ struct certificate_t {
* A certificate may contain additional issuer identifiers, which are
* not returned by get_issuer (e.g. issuerAltNames)
*
- * @param subject isser identity
- * @return matching value of best match
+ * @param subject issuer identity
+ * @return matching value of best match
*/
id_match_t (*has_issuer)(certificate_t *this, identification_t *issuer);
@@ -141,7 +143,7 @@ struct certificate_t {
* Check if this certificate is issued and signed by a specific issuer.
*
* @param issuer issuer's certificate
- * @return TRUE if certificate issued by issuer and trusted
+ * @return TRUE if certificate issued by issuer and trusted
*/
bool (*issued_by)(certificate_t *this, certificate_t *issuer);
@@ -176,7 +178,7 @@ struct certificate_t {
/**
* Check if two certificates are equal.
*
- * @param other certificate to compair against this
+ * @param other certificate to compare against this
* @return TRUE if certificates are equal
*/
bool (*equals)(certificate_t *this, certificate_t *other);
@@ -197,10 +199,10 @@ struct certificate_t {
/**
* Generic check if a given certificate is newer than another.
*
* @param this first certificate to check
* @param other second certificate
* @return TRUE if this newer than other
*/
-bool certificate_is_newer(certificate_t *this, certificate_t *other);
+bool certificate_is_newer(certificate_t *cert, certificate_t *other);
#endif /** CERTIFICATE_H_ @}*/
@@ -197,10 +199,10 @@ struct certificate_t {
* Generic check if a given certificate is newer than another.
*
- * @param this first certificate to check
- * @param other second certificate
+ * @param cert certificate
+ * @param other certificate to compare to
* @return TRUE if this newer than other
*/